cloudfeaster
============

|Maintained| |license| |PythonVersions| |status| |PyPI| |Requirements|
|CodeFactor| |Language grade: Python| |CircleCI| |codecov| |Total
alerts| |docker-simonsdave/cloudfeaster-dev-env|

Cloudfeaster is a web crawling and business process automation
infrastructure that leverages modern software engineering tools,
services and trends to create:

-  (this repo is) `a spider authoring and maintenance
   environment <https://github.com/simonsdave/cloudfeaster>`__
-  a service infrastructure for discovering and running spiders via a
   RESTful API

`This <docs/story.md>`__ is the story behind Cloudfeaster.

What Next
---------

-  `this <docs/spider_authors.md>`__ describes how to author spiders
   using Cloudfeaster
-  see `these <docs/contributing.md>`__ instructions describe how to
   setup your development environment and start contributing to
   Cloudfeaster
-  take a look at `cloudfeaster/samples <cloudfeaster/samples/>`__ for
   some spiders that illustrate the core concepts
-  and
   `simonsdave/gaming-spiders <https://github.com/simonsdave/gaming-spiders>`__
   is an entire repo of spiders so you can get a sense of the end-to-end

.. |Maintained| image:: https://img.shields.io/maintenance/yes/2020.svg?style=flat
.. |license| image:: https://img.shields.io/pypi/l/cloudfeaster.svg?style=flat
.. |PythonVersions| image:: https://img.shields.io/pypi/pyversions/cloudfeaster.svg?style=flat
.. |status| image:: https://img.shields.io/pypi/status/cloudfeaster.svg?style=flat
.. |PyPI| image:: https://img.shields.io/pypi/v/cloudfeaster.svg?style=flat
   :target: https://pypi.python.org/pypi/cloudfeaster
.. |Requirements| image:: https://requires.io/github/simonsdave/cloudfeaster/requirements.svg?branch=release-0.9.45
   :target: https://requires.io/github/simonsdave/cloudfeaster/requirements/?branch=release-0.9.45
.. |CodeFactor| image:: https://www.codefactor.io/repository/github/simonsdave/cloudfeaster/badge/release-0.9.45
   :target: https://www.codefactor.io/repository/github/simonsdave/cloudfeaster/overview/release-0.9.45
.. |Language grade: Python| image:: https://img.shields.io/lgtm/grade/python/g/simonsdave/cloudfeaster.svg?logo=lgtm&logoWidth=18
   :target: https://lgtm.com/projects/g/simonsdave/cloudfeaster/context:python
.. |CircleCI| image:: https://circleci.com/gh/simonsdave/cloudfeaster/tree/release-0.9.45.svg?style=shield
   :target: https://circleci.com/gh/simonsdave/cloudfeaster/tree/release-0.9.45
.. |codecov| image:: https://codecov.io/gh/simonsdave/cloudfeaster/branch/release-0.9.45/graph/badge.svg
   :target: https://codecov.io/gh/simonsdave/cloudfeaster
.. |Total alerts| image:: https://img.shields.io/lgtm/alerts/g/simonsdave/cloudfeaster.svg?logo=lgtm&logoWidth=18
   :target: https://lgtm.com/projects/g/simonsdave/cloudfeaster/alerts/
.. |docker-simonsdave/cloudfeaster-dev-env| image:: https://img.shields.io/badge/docker-simonsdave%2Fcloudfeaster--dev--env-blue.svg
   :target: https://hub.docker.com/r/simonsdave/cloudfeaster-dev-env
